Struct openlibrary_rs::search::Search
source · [−]pub struct Search { /* private fields */ }Expand description
The struct representation of a request to the Search API
The fields of this struct are private. If you want to view available fields that can be set please look at the SearchBuilder struct.
For more information on query strings and examples please view Openlibrary’s documentation.